print_command

Function print_command 

pub fn print_command(command: &str)
Prints detailed help for a specific command, including its description, usage, parameters, and auth requirements.

This is used when the user uses the help command with a specific command name as a parameter.